@@ -228,6 +228,18 @@ test_that("chop_evenly", {
 })
 
 
+test_that("brk_spikes", {
+  d_reps <- c(rep(d1[3], 5), d1[-3])
+
+  expect_silent(
+    res <- chop(d_reps, brk_spikes(db1, n = 5))
+  )
+
+  expect_in("{1975-10-29}", levels(res))
+  expect_equal(sum(res == "{1975-10-29}"), 5)
+})
+
+
 test_that("chop timezones", {
   dt_z1 <- seq(as.POSIXct("2000-01-01 09:00:00", tz = "GMT"),
         by = "hour", length.out = 24)
@@ -243,12 +255,14 @@ test_that("chop timezones", {
 
 test_that("Date labels", {
   li <- lbl_intervals()
-  b <- brk_res(brk_default(db1))
+  b <- brk_res(brk_default(db1), close_end = FALSE)
   expect_equivalent(
     li(b), "[1975-11-01, 1975-11-15)"
   )
 
-  b2 <- brk_res(brk_default(db1), x = as.Date("1975-01-01"), extend = TRUE)
+  withr::local_options(santoku.infinity = "Inf")
+  b2 <- brk_res(brk_default(db1), x = as.Date("1975-01-01"), extend = TRUE,
+                close_end = FALSE)
   expect_equivalent(
     li(b2), c("[-Inf, 1975-11-01)", "[1975-11-01, 1975-11-15)", "[1975-11-15, Inf]")
   )
@@ -272,11 +286,12 @@ test_that("Date labels", {
 
 test_that("POSIXct labels", {
   li <- lbl_intervals()
-  b <- brk_res(brk_default(dtb1))
+  b <- brk_res(brk_default(dtb1), close_end = FALSE)
   expect_equivalent(
     li(b), "[2000-01-01 15:04:00, 2000-01-01 15:14:00)"
   )
 
+  withr::local_options(santoku.infinity = "Inf")
   b2 <- brk_res(brk_default(dtb1), x = as.POSIXct("2000-01-01 15:00:00"), extend = TRUE)
   expect_equivalent(
     li(b2), c("[-Inf, 2000-01-01 15:04:00)",
