@@ -21,6 +21,9 @@ test_that("brk_manual", {
 
   expect_error(brk_res(brk_manual(c(1, 2, 2, 2, 3), rep(TRUE, 5))),
         regexp = "equal")
+
+  expect_warning(brk_res(brk_manual(1:3, rep(TRUE, 3)), left = FALSE))
+  expect_warning(brk_res(brk_manual(1:3, rep(TRUE, 3)), close_end = FALSE))
 })
 
 
@@ -183,23 +186,28 @@ test_that("brk_quantiles", {
   expect_silent(brks <- brk_quantiles(numeric(0))(x, TRUE, TRUE, FALSE))
   expect_equivalent(c(brks), c(-Inf, Inf))
 
-  x <- rep(1, 5)
-  brks <- brk_quantiles(1:3/4)(x, FALSE, TRUE, FALSE)
-  expect_equivalent(c(brks), c(1, 1))
-
   x <- 1:10
   brks <- brk_quantiles(1:3/4, weights = 1:10)(x, FALSE, TRUE, FALSE)
   expect_equivalent(c(brks), Hmisc::wtd.quantile(x, weights = 1:10, probs = 1:3/4))
 })
 
 
-test_that("bugfix #49: brk_quantiles() shouldn't ignore duplicate quantiles", {
+test_that("brk_quantiles with duplicate quantiles", {
+  x <- rep(1, 5)
+  expect_warning(brks <- brk_quantiles(1:3/4)(x, FALSE, TRUE, FALSE))
+  expect_equivalent(c(brks), c(1, 1))
+
   x <- c(1, 1, 2, 3, 4)
-  brks <- brk_quantiles(0:5/5)(x, FALSE, TRUE, FALSE)
+  expect_warning(brks <- brk_quantiles(0:5/5)(x, FALSE, TRUE, FALSE))
   expect_equivalent(c(brks), c(1.0, 1.0, 1.6, 2.4, 3.2, 4.0))
 
   x <- c(1, 1, 1, 2, 3)
-  brks <- brk_quantiles(0:5/5)(x, FALSE, TRUE, FALSE)
+  expect_warning(brks <- brk_quantiles(0:5/5)(x, FALSE, TRUE, FALSE))
+  expect_equivalent(c(brks), c(1.0, 1.0, 1.4, 2.2, 3.0))
+
+  expect_silent(
+    brks <- brk_quantiles(0:5/5, recalc_probs = TRUE)(x, FALSE, TRUE, FALSE)
+  )
   expect_equivalent(c(brks), c(1.0, 1.0, 1.4, 2.2, 3.0))
 })
 
@@ -251,6 +259,68 @@ test_that("brk_fn", {
 })
 
 
+test_that("brk_spikes", {
+  x <- c(rep(5, 5), 1:10)
+
+  expect_silent(
+    brks <- brk_res(brk_spikes(c(2, 8), n = 5), x = x)
+  )
+  expect_equivalent(
+    c(brks),
+    c(2, 5, 5, 8)
+  )
+
+  expect_silent(
+    brks2 <- brk_res(brk_spikes(c(2, 5, 8), n = 5), x = x)
+  )
+  expect_equivalent(
+    c(brks2),
+    c(2, 5, 5, 8)
+  )
+
+  expect_silent(
+    brks3 <- brk_res(brk_spikes(c(2, 5, 5, 8), n = 5), x = x)
+  )
+  expect_equivalent(
+    c(brks3),
+    c(2, 5, 5, 8)
+  )
+
+  x2 <- c(1, 1, 1, 2, 3, 3, 4, 4, 4, 4, 5, 6, 7, 8, 8, 8, 9)
+  expect_silent(
+    brks3.1 <- brk_res(brk_spikes(c(2, 8), n = 3), x = x2)
+  )
+  expect_equivalent(
+    c(brks3.1),
+    c(1, 1, 2, 4, 4, 8, 8)
+  )
+
+  expect_silent(
+    brks4 <- brk_res(brk_spikes(brk_width(5), n = 5), x = x)
+  )
+  expect_equivalent(
+    c(brks4),
+    c(1, 5, 5, 6, 11)
+  )
+
+  expect_silent(
+    brks5 <- brk_res(brk_spikes(c(2, 8), prop = 0.4), x = x)
+  )
+  expect_equivalent(
+    c(brks5),
+    c(2, 5, 5, 8)
+  )
+
+  expect_error(
+    brk_spikes(c(2, 8), n = 5, prop = 0.5)
+  )
+
+  expect_error(
+    brk_spikes(c(2, 8))
+  )
+})
+
+
 test_that("printing", {
   b <- brk_res(brk_default(1:3))
   expect_output(print(b))
