@@ -7,8 +7,7 @@ test_that("character", {
     chop(x, br)
   )
 
-  oo <- options(santoku.warn_character = FALSE)
-  on.exit(options(oo))
+  withr::local_options(santoku.warn_character = FALSE)
 
   expect_silent(
     chop(x, br)
