@@ -32,6 +32,7 @@ test_that("systematic tests", {
     brk_default_hi  = expression(brk_default(5)),
     brk_width       = expression(brk_width(1)),
     brk_width2      = expression(brk_width(1, 0)),
+    brk_spikes  = expression(brk_spikes(1:3, n = 2)),
     brk_w_difft_day = expression(brk_width(as.difftime(5, units = "days"))),
     brk_w_difft_sec = expression(brk_width(as.difftime(5, units = "secs"))),
     brk_def_Date    = expression(brk_default(as.Date("1950-01-05") + c(0, 5))),
@@ -67,7 +68,7 @@ test_that("systematic tests", {
   }
 
   skip_test(! left & brk_fun == "brk_manual")
-  skip_test(close_end & brk_fun == "brk_manual")
+  skip_test(! close_end & brk_fun == "brk_manual")
 
   POSIXct_breaks <- c("brk_def_POSIXct", "brk_w_difft_sec")
   Date_breaks <- c("brk_def_Date", "brk_w_difft_day")
@@ -102,7 +103,6 @@ test_that("systematic tests", {
   should_fail(char_by_quantities & test_df$lbl_fun == "lbl_midpoints"
               & test_df$brk_fun %in% c("brk_n", "brk_n_merge"))
 
-
   # brk_default_hi and _lo have a single break, so if you can't
   # extend it, there are no possible intervals:
   should_fail(with(test_df,
@@ -158,6 +158,12 @@ test_that("systematic tests", {
                  extend == TRUE & raw == TRUE
                ))
 
+  # brk_quantiles() should warn on duplicate quantiles
+  should_warn(with(test_df,
+                 names(x) %in% c("one", "same") &
+                 brk_fun == "brk_quantiles"
+               ))
+
   # brk_default has breaks 1,2,2,3
   # with lbl_endpoints, this may create duplicate left endpoints
   # ie the user asked for something we can't do
@@ -172,6 +178,11 @@ test_that("systematic tests", {
           lbl_fun == "lbl_endpoints" &
           drop == FALSE
         ))
+  dont_care(with(test_df,
+          brk_fun == "brk_spikes" &
+          lbl_fun == "lbl_endpoints" &
+          drop == FALSE
+        ))
   dont_care(with(test_df,
           brk_fun %in% c("brk_n", "brk_n_merge") &
           lbl_fun == "lbl_endpoints"
